# Njinn CLI

## Installation

You can install the Njinn CLI from [PyPI](https://pypi.org/project/njinn/):

    pip install njinn

The client is supported on Python 3.7 and above.

# Usage

- Pack install

    njinn pack install <repository_url>

Use --help to see available options and defaults.